==> quantify-0.0.4.tar.gz: quantify-0.0.4/README.md <==
# Quantify

![Quantify logo](https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/QUANTIFY_LANDSCAPE.svg)

[![Pipeline Status](https://gitlab.com/quantify-os/quantify/badges/main/pipeline.svg)](https://gitlab.com/quantify-os/quantify/-/pipelines)
[![Coverage](https://gitlab.com/quantify-os/quantify/badges/main/coverage.svg)](https://quantify-os.org/quantify/coverage/)
[![Codacy Badge](https://app.codacy.com/project/badge/Grade/bd24bae47c5d4c66855d78ad3b217f51)](https://app.codacy.com/gl/quantify-os/quantify/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
[![Code style: ruff](https://img.shields.io/badge/code%20style-ruff-005FFF.svg)](https://github.com/astral-sh/ruff)
[![PyPi](https://img.shields.io/pypi/v/quantify.svg)](https://pypi.org/pypi/quantify)
[![Docs](https://img.shields.io/badge/docs-latest-blue.svg)](https://quantify-os.gitlab.io/quantify/)
[![Slack](https://img.shields.io/badge/slack-chat-green.svg)](https://quantify-os.org/slack.html)
[![Contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg)](CONTRIBUTING.md)
[![License](https://img.shields.io/badge/License-BSD%203--Clause-blue.svg)](https://gitlab.com/quantify-os/quantify/-/blob/main/LICENSE)

Quantify is a Python-based data acquisition framework focused on Quantum Computing and
solid-state physics experiments.
Currently it is a metapackage for [quantify-core](https://pypi.org/project/quantify-core/)
([git repo](https://gitlab.com/quantify-os/quantify-core/))
and [quantify-scheduler](https://pypi.org/project/quantify-scheduler/)
([git repo](https://gitlab.com/quantify-os/quantify-scheduler/)).
They are built on top of [QCoDeS](https://qcodes.github.io/Qcodes/) and are a spiritual
successor of [PycQED](https://github.com/DiCarloLab-Delft/PycQED_py3).

Take a look at the latest documentation for
[quantify-core](https://quantify-quantify-core.readthedocs-hosted.com/) and
[quantify-scheduler](https://quantify-quantify-scheduler.readthedocs-hosted.com/)
for the usage instructions.

## Overview and Community

For a general overview of Quantify and connecting to its open-source community,
see [quantify-os.org](https://quantify-os.org/).
Quantify is maintained by the Quantify Consortium consisting of Qblox and
Orange Quantum Systems.

[<img src="https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/Qblox_logo.svg" alt="Qblox logo" width=200px/>](https://qblox.com)
&nbsp;
&nbsp;
&nbsp;
&nbsp;
[<img src="https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/OQS_logo_with_text.svg" alt="Orange Quantum Systems logo" width=200px/>](https://orangeqs.com)

&nbsp;

The software is licensed under a [BSD 3-clause license](https://gitlab.com/quantify-os/quantify/-/raw/main/LICENSE).

==> quantify-1.0.0b2.tar.gz: quantify-1.0.0b2/README.md <==
# Quantify

![Quantify logo](https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/QUANTIFY_LANDSCAPE.svg)

[![PyPI](https://img.shields.io/pypi/v/quantify.svg)](https://pypi.org/project/quantify/)
[![pipeline status](https://gitlab.com/quantify-os/quantify/badges/main/pipeline.svg)](https://gitlab.com/quantify-os/quantify/-/pipelines)
[![docs](https://img.shields.io/badge/docs-stable-informational.svg)](https://quantify-os.gitlab.io/quantify/)
[![code quality](https://app.codacy.com/project/badge/Grade/bd24bae47c5d4c66855d78ad3b217f51)](https://app.codacy.com/gl/quantify-os/quantify/dashboard?utm_source=gl&utm_medium=referral&utm_content=&utm_campaign=Badge_grade)
[![code style: ruff](https://img.shields.io/badge/code%20style-ruff-informational.svg)](https://docs.astral.sh/ruff/)
[![license: BSD-3-Clause](https://img.shields.io/badge/license-BSD--3--Clause-blue.svg)](./LICENSE)
[![contributions welcome](https://img.shields.io/badge/contributions-welcome-brightgreen.svg)](./CONTRIBUTING.md)
[![Slack](https://img.shields.io/badge/chat-Slack-purple.svg)](https://join.slack.com/t/quantify-hq/shared_invite/zt-1nd78r4e9-rbWdna53cW4DO_YbtMhVuA)

Quantify is a Python-based data acquisition framework focused on Quantum Computing and
solid-state physics experiments.
Currently it is a metapackage for [quantify-core](https://pypi.org/project/quantify-core/)
([git repo](https://gitlab.com/quantify-os/quantify-core/))
and [quantify-scheduler](https://pypi.org/project/quantify-scheduler/)
([git repo](https://gitlab.com/quantify-os/quantify-scheduler/)).
They are built on top of [QCoDeS](https://qcodes.github.io/Qcodes/) and are a spiritual
successor of [PycQED](https://github.com/DiCarloLab-Delft/PycQED_py3).

Take a look at the latest documentation for
[quantify-core](https://quantify-quantify-core.readthedocs-hosted.com/) and
[quantify-scheduler](https://quantify-quantify-scheduler.readthedocs-hosted.com/)
for the usage instructions.

## Overview and Community

For a general overview of Quantify and connecting to its open-source community,
see [quantify-os.org](https://quantify-os.org/).
Quantify is maintained by the Quantify Consortium consisting of Qblox and
Orange Quantum Systems.

[<img src="https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/Qblox_logo.svg" alt="Qblox logo" width=200px/>](https://qblox.com)
&nbsp;
&nbsp;
&nbsp;
&nbsp;
[<img src="https://gitlab.com/quantify-os/quantify/-/raw/main/docs/source/images/OQS_logo_with_text.svg" alt="Orange Quantum Systems logo" width=200px/>](https://orangeqs.com)

&nbsp;

The software is licensed under a [BSD 3-clause license](https://gitlab.com/quantify-os/quantify/-/raw/main/LICENSE).
